@@ -1,4 +1,5 @@
 """Synchronous and asynchronous clients for Notion's API."""
+import json
 import logging
 from abc import abstractclassmethod
 from dataclasses import dataclass
@@ -47,7 +48,7 @@ class ClientOptions:
     base_url: str = "https://api.notion.com"
     log_level: int = logging.WARNING
     logger: Optional[logging.Logger] = None
-    notion_version: str = "2021-08-16"
+    notion_version: str = "2022-02-22"
 
 
 class BaseClient:
@@ -86,7 +87,7 @@ class BaseClient:
         client.headers = httpx.Headers(
             {
                 "Notion-Version": self.options.notion_version,
-                "User-Agent": "ramnes/notion-sdk-py@0.9.0",
+                "User-Agent": "ramnes/notion-sdk-py@1.0.0",
             }
         )
         if self.options.auth:
@@ -114,8 +115,11 @@ class BaseClient:
         try:
             response.raise_for_status()
         except httpx.HTTPStatusError as error:
-            body = error.response.json()
-            code = body.get("code")
+            try:
+                body = error.response.json()
+                code = body.get("code")
+            except json.JSONDecodeError:
+                code = None
             if code and is_api_error_code(code):
                 raise APIResponseError(response, body["message"], code)
             raise HTTPResponseError(error.response)
