@@ -1,18 +1,19 @@
 import os
+from typing import List, Optional
 
 import pytest
 
 from notion_client import AsyncClient, Client
 
 
-def pytest_collection_modifyitems(items):
+def pytest_collection_modifyitems(items: List[pytest.Item]):
     for item in items:
         item.add_marker("asyncio")
 
 
 @pytest.fixture(scope="session")
 def vcr_config():
-    def remove_headers(response):
+    def remove_headers(response: dict):
         response["headers"] = {}
         return response
 
@@ -23,17 +24,17 @@ def vcr_config():
 
 
 @pytest.fixture(scope="session")
-def token():
+def token() -> Optional[str]:
     return os.getenv("NOTION_TOKEN")
 
 
 @pytest.fixture
-def client(token):
+def client(token: Optional[str]):
     return Client({"auth": token})
 
 
 @pytest.fixture
-async def async_client(token):
+async def async_client(token: Optional[str]):
     client = AsyncClient({"auth": token})
     yield client
     await client.aclose()
